smooth_chucker library
Classes
- ApiResponse
- ApiResponse is the API data model to save and retrieve from local storage
- SmoothChucker
- Main entry point for SmoothChucker package
- SmoothChuckerChopperInterceptor
- Chopper interceptor for SmoothChucker
- SmoothChuckerDioInterceptor
- Intercepts Dio requests and responses and stores them in the database
- SmoothChuckerHttpClient
- Custom HTTP client with SmoothChucker support
- SmoothChuckerHttpLoggingInterceptor
- Chopper HTTP logging interceptor for better readability
- SmoothChuckerProvider
- Provider for SmoothChucker state and configuration
Functions
-
unawaited(
Future< void> future) → void - Extension to mark unawaited futures
-
unawaitedForDio(
Future< void> future) → void - Extension to mark unawaited futures
-
unawaitedForHttp(
Future< void> future) → void - Extension to mark unawaited futures